@@ -87,12 +87,13 @@ class BitMEXRestApi:
 
         return await self._request(path='/execution/tradeHistory', query=query, verb='GET')
 
-    async def funding(self, symbol, start=0, count=100, reverse=False, start_time=None, end_time=None):
+    async def funding(self, symbol=None, start=0, count=100, reverse=False, start_time=None, end_time=None):
         query = {
-            'symbol': symbol,
             'start': start,
             'count': count,
         }
+        if symbol:
+            query['symbol'] = symbol
         if reverse:
             query['reverse'] = 'true'
         if start_time:
@@ -185,6 +186,13 @@ class BitMEXRestApi:
 
         return await self._request(path='/trade/bucketed', query=query)
 
+    async def user_wallet_history(self, count=1000, start=0):
+        return await self._request(path='/user/walletHistory', query={
+            'currency': 'XBt',
+            'start': start,
+            'count': count,
+        })
+
     async def _request(self, *, path, query=None, postdict=None, timeout=None, verb=None):
         """Send a request to BitMEX Servers."""
         if timeout is None:
